@@ -49,8 +49,10 @@
 
 package com.openexchange.unifiedinbox.copy;
 
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.concurrent.ExecutionException;
+import java.util.stream.Collectors;
 import com.openexchange.exception.OXException;
 import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.MailExceptionCode;
@@ -248,13 +250,7 @@ public final class UnifiedInboxMessageCopier {
      */
     private String[] transformMailId2UnifiedMailId(int account, String dest, String[] mailids) {
         UnifiedInboxUID helper = new UnifiedInboxUID();
-        String[] result = new String[mailids.length];
-        int x=0;
-        for(String id: mailids) {
-            result[x++] = helper.setUID(account, dest, id).toString();
-        }
-        
-        return result;
+        return Arrays.asList(mailids).stream().map((x) -> helper.setUID(account, dest, x).toString()).collect(Collectors.toList()).toArray(new String[mailids.length]);
     }
 
     private String[] accountFolder2AccountFolder(final String sourceFolder, final String destFolder, final String[] mailIds, final boolean fast, final boolean move) throws OXException {
